@@ -260,10 +260,11 @@ class Resource(AccessControlPermissionsMixin):
     ):
         """General get method for jobs, flowcharts, projects"""
 
-        from sqlalchemy import Column
-
         perm_query = cls.permissions_query(permission.lower())
 
+        if order.lower() == "desc":
+            perm_query = perm_query.order_by(cls.__dict__[sort_by].desc())
+
         if description is not None:
             # Build string
             perm_query = perm_query.filter(cls.description.contains(description))
@@ -277,11 +278,8 @@ class Resource(AccessControlPermissionsMixin):
         if offset is not None:
             perm_query = perm_query.offset(offset)
 
-        if order.lower() == "desc":
-            perm_query = perm_query.order_by(cls.__dict__[sort_by].desc())
-
         if only != "all":
-            perm_query = perm_query.values(Column(only))
+            perm_query = perm_query.values(*(cls.__dict__[x] for x in only))
             return perm_query
         else:
             return perm_query.all()
@@ -667,13 +665,14 @@ class Job(Base, Resource):
         local = locals()
         update_dict = {x: local[x] for x in possible_updates if local[x] is not None}
 
-        job = cls.query.get(id)
-
         for k, v in update_dict.items():
             if k == "submitted" or k == "finished" or k == "started":
-                update_dict[k] = datetime.fromtimestamp(v / 1000)
+                if v:
+                    update_dict[k] = datetime.fromtimestamp(v / 1000)
+                else:
+                    update_dict[k] = None
 
-        job.query.update(update_dict)
+        Job.query.filter(Job.id == id).update(update_dict)
 
         return job
 
@@ -786,5 +785,5 @@ class Project(Base, Resource):
         update_dict = {x: local[x] for x in possible_updates if local[x] is not None}
         project = Project.query.get(id)
 
-        project.query.update(update_dict)
+        Project.query.filter(Project.id == id).update(update_dict)
         return project
