@@ -62,14 +62,22 @@ def generate_association_table(
     def entity_relationship(cls):
         return relationship(
             f"{entity_name}",
-            backref=backref(f"special_{resource_tablename}", lazy="dynamic"),
+            backref=backref(
+                f"special_{resource_tablename}",
+                lazy="dynamic",
+                cascade="save-update, merge, " "delete, delete-orphan",
+            ),
         )
 
     @declared_attr
     def resource_relationship(cls):
         return relationship(
             f"{resource_name}",
-            backref=backref(f"special_{entity_tablename}", lazy="dynamic"),
+            backref=backref(
+                f"special_{entity_tablename}",
+                lazy="dynamic",
+                cascade="save-update, merge, " "delete, delete-orphan",
+            ),
         )
 
     class PermissionsAssociationMixin:
